==> deepin-system-monitor_1.0.0-1.tar.xz: deepin-system-monitor-1.4.8/translations/deepin-system-monitor_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>İşlem adı</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Komut satırı</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Başlama zamanı</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>İşlemci</translation>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation>Disk okuma</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Disk yazma</translation>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Bellek</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Takas</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Devre dışı</translation>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation>İndirme</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Toplam</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Yükleme</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>İşlemci</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Disk okuma</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Disk yazma</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Uygulamayı zorla sonlandır</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Koyu tema</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Uygulamayı sonlandır</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Bu uygulamayı sonlandırmak veri kaybına neden olabilir. Devam etmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation>Sade kip</translation>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Bellek</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Takas</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Devre dışı</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndirme</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Toplam</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Yükleme</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Yanıt yok</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>İşlemi sonlandır</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Bu işlemi sonlandırmak veri kaybına neden olabilir.
Devam etmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>İşlemi askıya al</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>İşlemi sürdür</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>İşlem konumunu görüntüle</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Özellikler</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 uygulama ve %3 işlem çalışıyor</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>İşlemci</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Bellek</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Disk yazma</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Disk okuma</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndirme</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Yükleme</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Deepin Sistem İzleyici, sezgisel olarak kullanılabilen güçlü bir sistem izleme uygulamasıdır. İşlemci, bellek, ağ, disk ve diğer işlemlerin durumunun izlenmesini sağlar.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin Sistem İzleyici</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin Sistem İzleyici</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Masaüstü Ortamı - İşlem başlatma hizmeti</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Masaüstü Ortamı - Masaüstü</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Masaüstü Ortamı - Polkit vekil sunucu</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Masaüstü Ortamı - Başlatıcı</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Masaüstü Ortamı - Görev Çubuğu</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Masaüstü Ortamı - Ekran görüntüsü</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Masaüstü Ortamı - Art Hizmet</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Masaüstü Ortamı - Oturum art hizmeti</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Masaüstü Ortamı - Oturum başlatma işlemi</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Deepin Dosya Yöneticisi art hizmeti</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Masaüstü Ortamı - Ekran kilitleme hizmeti</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Deepin Pencere Yöneticisi</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Deepin Pencere Yöneticisi değiştirici</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Deepin bildirim</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Deepin Bulut Yazdırma programı</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Deepin menü hizmeti</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Deepin Mağaza art hizmeti</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Pencere eşleştirme art hizmeti</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Pencere eşleştirme art hizmeti DBus hizmeti</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>SSH programı</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Kullanıcı kipi sanal dosya sistemi art hizmeti</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Kullanıcı kipi sanal dosya sistemi art hizmeti Fuse sunucusu</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Deepin Mağaza istemcisi yardımcı işlemi</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Ağ yöneticisi</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>PolicyKit DBus hizmeti</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Dosya paylaşım hizmeti art hizmeti</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>X hizmeti</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Fcitx giriş yöntemi</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Fcitx giriş yöntemi DBus art hizmeti</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Sogou giriş yöntemi art hizmeti</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>ShadowSocks yerel istemcisi</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Ses hizmeti</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Yazdırma art hizmeti</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Açık ekran yöneticisi</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Sistem hizmeti yöneticisi</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Sistem hizmeti yöneticisi - Aygıt yönetimi art hizmeti</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Disk art hizmeti</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Hesap art hizmeti</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>DBus art hizmeti</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Fare işlemi art hizmeti</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>DConf hizmeti</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Gnome anahtarlık art hizmeti</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Bluetooth art hizmeti</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Güç art hizmeti</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Modem aygıtı yöneticisi</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Sistem yazdırma tepsisi hizmeti</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Chrome tarayıcı kum havuzu</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Synaptics dokunmatik yüzey aygıtı art hizmeti</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Takas</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Devre dışı</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation>Sogou giriş yöntemi</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Sonlandırmak istediğiniz uygulamaya tıklayın</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Uygulamalar</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>İşlemlerim</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Tüm işlemler</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Tepsi</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Arama</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_1.4.3.orig.tar.xz: deepin-system-monitor-1.4.3/translations/deepin-system-monitor_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>İşlem adı</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Komut satırı</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Başlama zamanı</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Total</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>İşlemci</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Uygulamayı sonlandırmak için zorla</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Koyu tema</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Uygulamayı sonlandır</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Bu uygulamayı sonlandırmak veri kaybına neden olabilir. Devam etmeye emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Bellek</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Takas</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Etkin değil</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndirme</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Toplam</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Yükleme</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Cevap yok</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>İşlemi sonlandır</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Bu işlemi sonlandırmak veri kaybına neden olabilir. Devam etmeye emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>İşlemi askıya al</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>İşlemi devam ettir</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>İşlem yerini görüntüle</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Özellikleri</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 uygulama ve %3 süreç çalışıyor</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>İşlemci</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Bellek</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Disk yazma</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Disk okuma</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndirme</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Yükleme</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Deepin Sistem İzleyici, sezgisel ve güçlü bir sistem izleyicidir. İşlemci, bellek, ağ, disk ve diğer süreçlerin durumunu izleyebilirsiniz.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin Sistem İzleyici</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin Sistem İzleyici</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Masaüstü Ortamı - Süreç başlatma hizmeti</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Masaüstü Ortamı - Masaüstü</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Masaüstü Ortamı - Polkit vekil</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Masaüstü Ortamı - Başlatıcı</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Masaüstü Ortamı - Rıhtım</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Masaüstü Ortamı - Ekran görüntüsü</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Masaüstü Ortamı - Program</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Masaüstü Ortamı - Oturum programı</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Masaüstü Ortamı - Oturum başlatma işlemi</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Deepin Dosya Yönetici programı</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Masaüstü Ortamı - Kilit ekran hizmeti</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Deepin Pencere Yönetici</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Derin Pencere Yönetici değiştiricisi</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Deepin bildirim</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Deepin Bulut Yazıcı ajanı</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Deepin menü servisi</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Deepin Mağaza programı</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Pencere eşleştirme programı</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Pencere eşleştirme programı DBus servisi</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>SSH ajanı</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Kullanıcı modu sanal dosya sistemi programı</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Kullanıcı modu sanal dosya sistem sigorta sunucu programı</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Deepin Mağaza müşterisinin yardımcı işlemi</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Ağ yönetici</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>PolicyKit DBus servisi</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Dosya paylaşım hizmeti programı</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>X servisi</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Fcitx giriş metodu</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Fcitx giriş metodu DBus programı</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Sogou giriş metodu programı</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>ShadowSocks yerel istemci</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Ses servisi</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Yazıcı programı</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Hafif ekran yönetici</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Sistem servis yönetici</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Sistem servis yönetici - Aygıt yönetim programı</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Disk programı</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Hesap programı</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>DBus programı</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Fare durum programı</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>DConf servisi</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Gnome anahtarlık programı</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Bluetooth programı</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Güç programı</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Modem aygıt yönetici</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Sistem baskı tepsisi servisi</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Chrome tarayıcı sanal alanı</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Synaptics dokunmatik yüzey aygıt programı</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Takas</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Etkin değil</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Sonlandırmak istediğiniz uygulamaya tıklayınız</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Uygulamalar</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>İşlemlerim</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Tüm işlemler</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
</TS>
